@@ -70,7 +70,7 @@ def test_premain_custom_rc(shell, tmpdir, monkeypatch, xession):
 
 
 @pytest.mark.skipif(
-    ON_WINDOWS and sys.version[:3] == "3.8",
+    ON_WINDOWS and sys.version_info[:3] == "3.8",
     reason="weird failure on py38+windows",
 )
 def test_rc_with_modules(shell, tmpdir, monkeypatch, capsys, xession):
@@ -329,7 +329,7 @@ def test_rc_with_failing_module(shell, tmpdir, monkeypatch, capsys, xession):
 
     stdout, stderr = capsys.readouterr()
     assert len(stdout) == 0
-    assert "RuntimeError: Unexpected error" in stderr
+    assert "Unexpected error" in stderr
 
     # Check that the temporary rc's folder is not left behind on the path
     assert tmpdir.strpath not in sys.path
