@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
 """Directory stack and associated utilities for the xonsh shell.
 https://www.gnu.org/software/bash/manual/html_node/Directory-Stack-Builtins.html
 """
-
+import contextlib
 import glob
 import os
 import subprocess
 import typing as tp
-from contextlib import contextmanager
 
 from xonsh.built_ins import XSH
 from xonsh.cli_utils import Annotated, Arg, ArgParserAlias
@@ -21,6 +19,27 @@ _unc_tempDrives: tp.Dict[str, str] = {}
 """ drive: sharePath for temp drive letters we create for UNC mapping"""
 
 
+@contextlib.contextmanager
+def _win_reg_key(*paths, **kwargs):
+    import winreg
+
+    key = winreg.OpenKey(*paths, **kwargs)
+    yield key
+    winreg.CloseKey(key)
+
+
+def _query_win_reg_key(*paths):
+    import winreg
+
+    *paths, name = paths
+
+    with contextlib.suppress(OSError):
+        with _win_reg_key(*paths) as key:
+            wval, wtype = winreg.QueryValueEx(key, name)
+            return wval
+
+
+@tp.no_type_check
 def _unc_check_enabled() -> bool:
     r"""Check whether CMD.EXE is enforcing no-UNC-as-working-directory check.
 
@@ -35,26 +54,18 @@ def _unc_check_enabled() -> bool:
 
     import winreg
 
-    wval = None
-
-    try:
-        key = winreg.OpenKey(
-            winreg.HKEY_CURRENT_USER, r"software\microsoft\command processor"
-        )
-        wval, wtype = winreg.QueryValueEx(key, "DisableUNCCheck")
-        winreg.CloseKey(key)
-    except OSError:
-        pass
+    wval = _query_win_reg_key(
+        winreg.HKEY_CURRENT_USER,
+        r"software\microsoft\command processor",
+        "DisableUNCCheck",
+    )
 
     if wval is None:
-        try:
-            key2 = winreg.OpenKey(
-                winreg.HKEY_LOCAL_MACHINE, r"software\microsoft\command processor"
-            )
-            wval, wtype = winreg.QueryValueEx(key2, "DisableUNCCheck")
-            winreg.CloseKey(key2)
-        except OSError as e:  # NOQA
-            pass
+        wval = _query_win_reg_key(
+            winreg.HKEY_LOCAL_MACHINE,
+            r"software\microsoft\command processor",
+            "DisableUNCCheck",
+        )
 
     return False if wval else True
 
@@ -88,21 +99,19 @@ def _unc_map_temp_drive(unc_path) -> str:
 
     if not _unc_check_enabled():
         return unc_path
-    else:
-        unc_share, rem_path = os.path.splitdrive(unc_path)
-        unc_share = unc_share.casefold()
-        for d in _unc_tempDrives:
-            if _unc_tempDrives[d] == unc_share:
-                return os.path.join(d, rem_path)
+    unc_share, rem_path = os.path.splitdrive(unc_path)
+    unc_share = unc_share.casefold()
+    for d in _unc_tempDrives:
+        if _unc_tempDrives[d] == unc_share:
+            return os.path.join(d, rem_path)
 
-        for dord in range(ord("z"), ord("a"), -1):
-            d = chr(dord) + ":"
-            if not os.path.isdir(d):  # find unused drive letter starting from z:
-                subprocess.check_output(
-                    ["NET", "USE", d, unc_share], universal_newlines=True
-                )
-                _unc_tempDrives[d] = unc_share
-                return os.path.join(d, rem_path)
+    for dord in range(ord("z"), ord("a"), -1):
+        d = chr(dord) + ":"
+        if not os.path.isdir(d):  # find unused drive letter starting from z:
+            subprocess.check_output(["NET", "USE", d, unc_share], text=True)
+            _unc_tempDrives[d] = unc_share
+            return os.path.join(d, rem_path)
+    raise RuntimeError(f"Failed to find a drive for UNC Path({unc_path})")
 
 
 def _unc_unmap_temp_drive(left_drive, cwd):
@@ -125,9 +134,7 @@ def _unc_unmap_temp_drive(left_drive, cwd):
             return
 
     _unc_tempDrives.pop(left_drive)
-    subprocess.check_output(
-        ["NET", "USE", left_drive, "/delete"], universal_newlines=True
-    )
+    subprocess.check_output(["NET", "USE", left_drive, "/delete"], text=True)
 
 
 events.doc(
@@ -221,11 +228,11 @@ def cd(args, stdin=None):
                 try:
                     num = int(d[1:])
                 except ValueError:
-                    return "", "cd: Invalid destination: {0}\n".format(d), 1
+                    return "", f"cd: Invalid destination: {d}\n", 1
                 if num == 0:
                     return None, None, 0
                 elif num < 0:
-                    return "", "cd: Invalid destination: {0}\n".format(d), 1
+                    return "", f"cd: Invalid destination: {d}\n", 1
                 elif num > len(DIRSTACK):
                     e = "cd: Too few elements in dirstack ({0} elements)\n"
                     return "", e.format(len(DIRSTACK)), 1
@@ -237,18 +244,18 @@ def cd(args, stdin=None):
         return (
             "",
             (
-                "cd takes 0 or 1 arguments, not {0}. An additional `-P` "
+                "cd takes 0 or 1 arguments, not {}. An additional `-P` "
                 "flag can be passed in first position to follow symlinks."
                 "\n".format(len(args))
             ),
             1,
         )
     if not os.path.exists(d):
-        return "", "cd: no such file or directory: {0}\n".format(d), 1
+        return "", f"cd: no such file or directory: {d}\n", 1
     if not os.path.isdir(d):
-        return "", "cd: {0} is not a directory\n".format(d), 1
+        return "", f"cd: {d} is not a directory\n", 1
     if not os.access(d, os.X_OK):
-        return "", "cd: permission denied: {0}\n".format(d), 1
+        return "", f"cd: permission denied: {d}\n", 1
     if (
         ON_WINDOWS
         and _is_unc_path(d)
@@ -509,9 +516,9 @@ def dirs_fn(
     if verbose:
         out = ""
         pad = len(str(len(o) - 1))
-        for (ix, e) in enumerate(o):
+        for ix, e in enumerate(o):
             blanks = " " * (pad - len(str(ix)))
-            out += "\n{0}{1} {2}".format(blanks, ix, e)
+            out += f"\n{blanks}{ix} {e}"
         out = out[1:]
     elif print_long:
         out = "\n".join(o)
@@ -549,7 +556,7 @@ def dirs_fn(
 dirs = ArgParserAlias(prog="dirs", func=dirs_fn, has_args=True)
 
 
-@contextmanager
+@contextlib.contextmanager
 def with_pushd(d):
     """Use pushd as a context manager"""
     pushd_fn(d)
